@@ -1,7 +1,20 @@
 /* Driver of Modula-2 translator.
-   Copyright (C) 1993-1997 (see more details in file COPYING).
-
-   This file is part of Modula-2 translator.  */
+ * Copyright 1993, 1994, 1995, 1996, 1997 Vladimir Makarov
+ * This file is part of m2c.
+ *
+ * m2c is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
+ *
+ * m2c is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+ * for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with m2c. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "m2-common.h"
 #include "m2-syntax.h"
@@ -10,6 +23,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/wait.h>
 #include <signal.h>
 #include <setjmp.h>
 
@@ -164,7 +178,7 @@ delete_c_output_files ()
        file_name_ptr <= (char **) VLS_END (names_of_c_output_files);
        file_name_ptr++)
     {
-      delete (*file_name_ptr);
+      unlink (*file_name_ptr);
       M2C_FREE (*file_name_ptr);
     }
 }
@@ -176,10 +190,8 @@ delete_c_output_files ()
    var = getenv (environment_var);\
    if (var == NULL) var = default_value;}while(FALSE)
 
-void
-main (argc, argv)
-     register int argc;
-     register char *argv[];
+int
+main (int argc, char *argv[])
 {
   register int i, okay;
   int option_has_parameter;
@@ -987,7 +999,7 @@ make_others ()
 	      if (current_modula_output_file_name != NULL)
 		{
 		  if (!okay_after_Modula_to_C || IS_MODULA_OUTPUT_DELETED)
-		    delete (current_modula_output_file_name);
+		    unlink (current_modula_output_file_name);
 		  M2C_FREE (current_modula_output_file_name);
 		  current_modula_output_file_name = NULL;
 		}
@@ -1134,7 +1146,7 @@ m2c_exit (code)
 {
   if (code != 0 && current_modula_output_file_name != NULL)
     {
-      delete (current_modula_output_file_name);
+      unlink (current_modula_output_file_name);
       M2C_FREE (current_modula_output_file_name);
       current_modula_output_file_name = NULL;
     }
@@ -1681,7 +1693,7 @@ C_compilation (after_modula, input_file_name, original_argument_number)
       mv_argument_vector[3] = NULL;
       okay = create_and_wait_for_process (MV, mv_argument_vector);
       if (!okay)
-	delete (mv_argument_vector[1]);
+	unlink (mv_argument_vector[1]);
       M2C_FREE (mv_argument_vector[1]);
     }
   if (C_OUTPUT_EXISTS)
