@@ -1,7 +1,20 @@
 /* Scanner of GNU Modula-2 translator.
-   Copyright (C) 1993-1997 (see more details in file COPYING).
-
-   This file is part of Modula-2 translator.  */
+ * Copyright 1993, 1994, 1995, 1996, 1997 Vladimir Makarov
+ * This file is part of m2c.
+ *
+ * m2c is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
+ *
+ * m2c is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+ * for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with m2c. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "m2-common.h"
 #include "m2-scanner.h"
